@@ -168,7 +168,7 @@
 (define (autoplay-foundations)
   (define (autoplay-foundations-tail)
     (if (or-map button-double-clicked '(5 6 7 8 9 10 11))
-        (autoplay-foundations-tail)
+        (delayed-call autoplay-foundations-tail)
         #t))
   (if (or-map button-double-clicked '(5 6 7 8 9 10 11))
       (autoplay-foundations-tail)
@@ -199,7 +199,10 @@
   (give-status-message))
 
 (define (game-won)
-  #f)
+  (and (= 13 (length (get-cards 1)))
+       (= 13 (length (get-cards 2)))
+       (= 13 (length (get-cards 3)))
+       (= 13 (length (get-cards 4)))))
 
 (define (check-to-foundation? slot)
   (cond ((= slot 12)
