@@ -2,31 +2,34 @@
 
 import os, os.path
 import gettext
-#DOMAIN = 'glchess'
+
 DOMAIN = 'gnome-games'
 gettext.bindtextdomain(DOMAIN)
 gettext.textdomain(DOMAIN)
 from gettext import gettext as _
+
 import gtk.glade
 gtk.glade.bindtextdomain (DOMAIN)
 gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.17.4"
+VERSION = "2.17.5"
 APPNAME = _("glChess")
 
-COPYRIGHT     = _('Copyright 2005-2006 Robert Ancell (and contributors)')
+COPYRIGHT     = _('Copyright 2005-2007 Robert Ancell (and contributors)')
 DESCRIPTION   = _('A 2D/3D chess interface for Gnome')
 WEBSITE       = 'http://glchess.sourceforge.net'
 WEBSITE_LABEL = _('glChess homepage')
 AUTHORS       = ['Robert Ancell <bob27@users.sourceforge.net>']
 ARTISTS       = ['John-Paul Gignac (3D Models)', 'Max Froumentin (2D Models)', 'Hylke Bons <h.bons@student.rug.nl> (icon)']
-TRANSLATORS   = """Luca Marturana <lucamarturana@gmail.com> (It)
-Hakan Bekdas <hakanbekdas@yahoo.com> (tr)
-A S Alam <apbrar@gmail.com> (pa)
-Michał Bentkowski <mr.ecik@mail.com> (pl)
-Daniel Nylander <po@danielnylander.se> (sv)
-Translators on Rosetta (launchpad.net)
-Gnome Translation Team"""
+TRANSLATORS   = [u"Luca Marturana <lucamarturana@gmail.com> (It)",
+                 u"Hakan Bekdas <hakanbekdas@yahoo.com> (tr)",
+                 u"A S Alam <apbrar@gmail.com> (pa)",
+                 u"Michał Bentkowski <mr.ecik@mail.com> (pl)",
+                 u"Daniel Nylander <po@danielnylander.se> (sv)",
+                 u"Zoraks <skatala4ever@gmail.com> (ca)",
+                 u"Elxan İsmayılov <elxan.i@gmail.com> (az)",
+                 u"Translators on Rosetta (launchpad.net)",
+                 u"Gnome Translation Team"]
 LICENSE = """This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 2 as published by the Free Software Foundation.
 
 This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details. 
