@@ -87,9 +87,10 @@ class HumanPlayer(game.ChessPlayer):
         """
         game.ChessPlayer.__init__(self, name)
         self.__game = chessGame
-        
+
     def readyToMove(self):
         # FIXME: ???
+        self.__game.view.controller.setAttention(True)
         self.__game.scene.setHumanPlayer(self)
         self.__game.cairoScene.setHumanPlayer(self)
 
@@ -97,14 +98,14 @@ class AIPlayer(ai.Player):
     """
     """
     
-    def __init__(self, application, name, profile, description):
+    def __init__(self, application, name, profile, level, description):
         """
         """
         executable = profile.path
         for arg in profile.arguments[1:]:
             executable += ' ' + arg
         self.window = application.ui.addAIWindow(profile.name, executable, description)
-        ai.Player.__init__(self, name, profile)
+        ai.Player.__init__(self, name, profile, level)
         
     def logText(self, text, style):
         """Called by ai.Player"""
@@ -245,6 +246,7 @@ class SceneCairo(scene.cairo.Scene, scene.human.SceneHumanInput):
             colour = chess.board.BLACK
         move = chess.lan.encode(colour, start, end, promotionType = chess.board.QUEEN) # FIXME: Promotion type
         player.move(move)
+        self.__game.view.controller.setAttention(False)
 
 class SceneOpenGL(scene.opengl.Scene, scene.human.SceneHumanInput):
     """
@@ -385,6 +387,7 @@ class SceneOpenGL(scene.opengl.Scene, scene.human.SceneHumanInput):
             colour = chess.board.BLACK
         move = chess.lan.encode(colour, start, end, promotionType = chess.board.QUEEN) # FIXME: Promotion type
         player.move(move)
+        self.__game.view.controller.setAttention(False)
 
 class Splashscreen(ui.ViewFeedback):
     """
@@ -556,16 +559,17 @@ class ChessGame(game.ChessGame):
         self.__movePlayer = MovePlayer(self)
         self.addSpectator(self.__movePlayer)
 
-    def addAIPlayer(self, name, profile):
+    def addAIPlayer(self, name, profile, level):
         """Create an AI player.
         
         'name' is the name of the player to create (string).
         'profile' is the the AI profile to use (ai.Profile).
+        'level' is the difficulty level to use (string).
         
         Returns an AI player to use (game.ChessPlayer).
         """
         description = "'" + name + "' in '" + self.name + "'"
-        player = AIPlayer(self.application, name, profile, description)
+        player = AIPlayer(self.application, name, profile, level, description)
         self.__aiPlayers.append(player)
         self.application.watchAIPlayer(player)
         return player
@@ -608,10 +612,15 @@ class ChessGame(game.ChessGame):
         pgnGame.setTag(pgnGame.PGN_TAG_WHITE, white.getName())
         pgnGame.setTag(pgnGame.PGN_TAG_BLACK, black.getName())
 
+        # FIXME: AI levels
         if isinstance(white, ai.Player):
-            pgnGame.setTag('WhiteAI', white.getProfile().name)
+            (profile, level) = white.getProfile()
+            pgnGame.setTag('WhiteAI', profile)
+            pgnGame.setTag('WhiteLevel', level)
         if isinstance(black, ai.Player):
-            pgnGame.setTag('BlackAI', black.getProfile().name)
+            (profile, level) = black.getProfile()
+            pgnGame.setTag('BlackAI', profile)
+            pgnGame.setTag('BlackLevel', level)
 
         moves = self.getMoves()
         while len(moves) > 0:
@@ -681,16 +690,21 @@ class UI(gtkui.GtkUI):
             player.read()
             return True
 
-    def onGameStart(self, gameName, allowSpectators, whiteName, whiteType, blackName, blackType, moves = None):
+    def onGameStart(self, gameName, allowSpectators, duration, white, black):
         """Called by UI"""
-        g = self.__application.addGame(gameName, whiteName, whiteType, blackName, blackType)
-        print 'Starting game ' + gameName + ' between ' + whiteName + '(' + str(whiteType) + ') and ' + blackName + '(' + str(blackType) + ')'
-        if moves:
-            g.start(moves)
+        if white.type is ui.HUMAN:
+            w = None
         else:
-            g.start()
+            w = (white.type, white.level)
+        if black.type is ui.HUMAN:
+            b = None
+        else:
+            b = (black.type, black.level)
+        g = self.__application.addGame(gameName, white.name, w, black.name, b)
+        print 'Starting game ' + gameName + ' between ' + white.name + '(' + str(white.type) + ') and ' + black.name + '(' + str(black.type) + ')'
+        g.start()
         
-    def loadGame(self, path, returnResult):
+    def loadGame(self, path):
         """Called by ui.UI"""
         try:
             p = chess.pgn.PGN(path, 1)
@@ -699,35 +713,7 @@ class UI(gtkui.GtkUI):
             return
         
         # Use the first game
-        pgnGame = p[0]
-        
-        if returnResult is True:
-            whiteAI = pgnGame.getTag('WhiteAI')
-            blackAI = pgnGame.getTag('BlackAI')
-            msg = ''
-            if whiteAI and self.__application.getAIProfile(whiteAI) is None:
-                msg += "AI '" + whiteAI + "' is not installed, white player is now human"
-                whiteAI = None
-            if blackAI and self.__application.getAIProfile(blackAI) is None:
-                if msg != '':
-                    msg += '\n'
-                msg += "AI '" + blackAI + "' is not installed, black player is now human"
-                blackAI = None
-
-            self.reportGameLoaded(gameName = pgnGame.getTag(pgnGame.PGN_TAG_EVENT),
-                                  whiteName = pgnGame.getTag(pgnGame.PGN_TAG_WHITE),
-                                  blackName = pgnGame.getTag(pgnGame.PGN_TAG_BLACK),
-                                  whiteAI = whiteAI, blackAI = blackAI,
-                                  moves = pgnGame.getMoves())
-                                  
-            if len(msg) > 0:
-                self.reportError('Game modified', msg)
-        else:
-            self.__application.addPGNGame(pgnGame, path)
-
-    def onGameJoin(self, localName, localType, game):
-        """Called by UI"""
-        print 'Joining game ' + str(game) + ' as ' + localName + '(' + str(localType) + ')'
+        self.__application.addPGNGame(p[0], path)
 
     def onQuit(self):
         """Called by UI"""
@@ -821,12 +807,14 @@ class Application:
         
         'name' is the name of the game (string).
         'whiteName' is the name of the white player (string).
-        'whiteType' is the AI profile to use for white (string) or None if white is human.
+        'whiteType' is a 2-tuple containing the AI profile name and difficulty level (str, str) or None for human players.
         'blackName' is the name of the black player (string).
-        'blackType' is the AI profile to use for black (string) or None if black is human.
+        'blackType' is a 2-tuple containing the AI profile name and difficulty level (str, str) or None for human players.
         
         Returns the game object. Use game.start() to start the game.
         """
+        # FIXME: Replace arguments with player objects
+        
         # Create the game
         g = ChessGame(self, name)
         self.__games.append(g)
@@ -835,23 +823,27 @@ class Application:
         if whiteType is None:
             player = g.addHumanPlayer(whiteName)
         else:
+            (profileName, level) = whiteType
             try:
-                profile = self.__aiProfiles[whiteType]
-                player = g.addAIPlayer(whiteName, profile)
+                profile = self.__aiProfiles[profileName]
             except KeyError:
                 msg += "AI '" + whiteType + "' is not installed, white player is now human"
                 player = g.addHumanPlayer(whiteName)
+            else:
+                player = g.addAIPlayer(whiteName, profile, level)
         g.setWhite(player)
 
         if blackType is None:
             player = g.addHumanPlayer(blackName)
         else:
+            (profileName, level) = blackType
             try:
-                profile = self.__aiProfiles[blackType]
-                player = g.addAIPlayer(blackName, profile)
+                profile = self.__aiProfiles[profileName]
             except KeyError:
                 msg += "AI '" + blackType + "' is not installed, black player is now human"
                 player = g.addHumanPlayer(blackName)
+            else:
+                player = g.addAIPlayer(blackName, profile, level)
         g.setBlack(player)
                 
         if len(msg) > 0:
@@ -867,11 +859,27 @@ class Application:
         
         Returns the game object. Use game.start() to start the game.
         """
+        whiteType = pgnGame.getTag('WhiteAI')
+        if whiteType is None:
+            w = None
+        else:
+            level = pgnGame.getTag('WhiteLevel')
+            if level is None:
+                level = 'normal'
+            w = (whiteType, level)
+
+        blackType = pgnGame.getTag('BlackAI')
+        if blackType is None:
+            b = None
+        else:
+            level = pgnGame.getTag('BlackLevel')
+            if level is None:
+                level = 'normal'
+            b = (blackType, level)
+
         g = self.addGame(pgnGame.getTag(pgnGame.PGN_TAG_EVENT),
-                         pgnGame.getTag(pgnGame.PGN_TAG_WHITE),
-                         pgnGame.getTag('WhiteAI'),
-                         pgnGame.getTag(pgnGame.PGN_TAG_BLACK),
-                         pgnGame.getTag('BlackAI'))
+                         pgnGame.getTag(pgnGame.PGN_TAG_WHITE), w,
+                         pgnGame.getTag(pgnGame.PGN_TAG_BLACK), b)
         g.fileName = path
         moves = pgnGame.getMoves()
         if moves:
@@ -916,7 +924,7 @@ class Application:
                 p = chess.pgn.PGN(path, 1)
             except chess.pgn.Error, e:
                 # TODO: Pop-up dialog
-                print e
+                print 'Unable to open PGN file ' + path + ':' + str(e)
             else:
                 # Use the first game
                 if len(p) > 0:
