@@ -371,7 +371,9 @@ configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
 static gint
 network_loop (gpointer data)
 {
-  network_move_worms ();
+  if (ggz_network_mode) { 
+    network_move_worms ();
+  }
   return TRUE;
 }
 #endif
@@ -386,7 +388,7 @@ new_game_2_cb (GtkWidget * widget, gpointer data)
 				      G_CALLBACK (key_press_cb), NULL);
 #ifdef GGZ_CLIENT
     if (!main_id && ggz_network_mode && network_is_host ()) {
-      main_id = g_timeout_add (GAMEDELAY * properties->gamespeed,
+      main_id = g_timeout_add (GAMEDELAY * (properties->gamespeed + NETDELAY),
 			       (GSourceFunc) network_loop, NULL);
     } else
 #endif
@@ -657,7 +659,10 @@ main_loop (gpointer data)
       g_signal_handler_disconnect (G_OBJECT (window), keyboard_id);
       keyboard_id = 0;
     }
-    main_id = 0;
+    if (main_id) {
+      g_source_remove (main_id);
+      main_id = 0;
+    }
     if (add_bonus_id) {
       g_source_remove (add_bonus_id);
     }
@@ -706,8 +711,11 @@ main_loop (gpointer data)
     if (add_bonus_id) {
       g_source_remove (add_bonus_id);
     }
+    if (main_id) {
+      g_source_remove (main_id);
+      main_id = 0;
+    }
     add_bonus_id = 0;
-    main_id = 0;
     erase_id = g_timeout_add (ERASETIME / ERASESIZE,
 			      (GSourceFunc) erase_worms_cb,
 			      (gpointer) ERASESIZE);
@@ -727,7 +735,10 @@ main_loop (gpointer data)
       g_source_remove (add_bonus_id);
     }
     add_bonus_id = 0;
-    main_id = 0;
+    if (main_id) {
+      g_source_remove (main_id);
+      main_id = 0;
+    }
     if ((current_level < MAXLEVEL) && (!properties->random
 				       || ggz_network_mode))
       current_level++;
