@@ -21,10 +21,10 @@
 
 #include <config.h>
 #include <gnome.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include <sys/time.h>
 #include <string.h>
 #include <games-stock.h>
+#include <games-gridframe.h>
 
 #include "gbdefs.h"
 #include "statusbar.h"
@@ -36,10 +36,14 @@
 #include "game.h"
 #include "cursors.h"
 
+/* Minimum sizes. */
+#define MINIMUM_TILE_WIDTH   8
+#define MINIMUM_TILE_HEIGHT  MINIMUM_TILE_WIDTH
+
 /**********************************************************************/
 /* Exported Variables                                                 */
 /**********************************************************************/
-GtkWidget *app       = NULL;
+GtkWidget *app = NULL;
 GtkWidget *game_area = NULL;
 /**********************************************************************/
 
@@ -47,32 +51,36 @@ GtkWidget *game_area = NULL;
 /**********************************************************************/
 /* File Static Variables                                              */
 /**********************************************************************/
-static gchar  *cmdline_scenario = NULL;
-static gchar  *cmdline_config   = NULL;
-static gint    session_xpos     = -1;
-static gint    session_ypos     = -1;
+static gchar *cmdline_scenario = NULL;
+static gchar *cmdline_config = NULL;
+static gint session_xpos = -1;
+static gint session_ypos = -1;
 /**********************************************************************/
 
 
 /**********************************************************************/
 /* File Static Variables                                              */
 /**********************************************************************/
-static struct poptOption options[] = {
-  {"scenario", 's', POPT_ARG_STRING, &cmdline_scenario, 0, 
+static const GOptionEntry options[] = {
+  {"scenario", 's', 0, G_OPTION_ARG_STRING, &cmdline_scenario,
    N_("Set game scenario"), N_("NAME")},
-  {"config", 'c', POPT_ARG_STRING, &cmdline_config, 0, 
+  {"config", 'c', 0, G_OPTION_ARG_STRING, &cmdline_config,
    N_("Set game configuration"), N_("NAME")},
-  {"x", 'x', POPT_ARG_INT, &session_xpos, 0, NULL, N_("X")},
-  {"y", 'y', POPT_ARG_INT, &session_ypos, 0, NULL, N_("Y")},
-  {NULL, '\0', 0, NULL, 0}
+  {"x", 'x', 0, G_OPTION_ARG_INT, &session_xpos,
+   N_("Initial window position"), N_("X")},
+  {"y", 'y', 0, G_OPTION_ARG_INT, &session_ypos,
+   N_("Initial window position"), N_("Y")},
+  {NULL},
 };
+
 /**********************************************************************/
 
 
 /**********************************************************************/
 /* Function Prototypes                                                */
 /**********************************************************************/
-static gint   save_state(GnomeClient*, gint, GnomeRestartStyle, gint, GnomeInteractStyle, gint, gpointer);
+static gint save_state (GnomeClient *, gint, GnomeRestartStyle, gint,
+			GnomeInteractStyle, gint, gpointer);
 /**********************************************************************/
 
 
@@ -97,14 +105,12 @@ static gint   save_state(GnomeClient*, gint, GnomeRestartStyle, gint, GnomeInter
  * TRUE on success, FALSE otherwise
  **/
 static gint
-save_state (
-            GnomeClient        *client,
-            gint                phase,
-            GnomeRestartStyle   save_style,
-            gint                shutdown,
-            GnomeInteractStyle  interact_style,
-            gint                fast,
-            gpointer            client_data)
+save_state (GnomeClient * client,
+	    gint phase,
+	    GnomeRestartStyle save_style,
+	    gint shutdown,
+	    GnomeInteractStyle interact_style,
+	    gint fast, gpointer client_data)
 {
   char *argv[20];
   int i;
@@ -113,11 +119,11 @@ save_state (
   gdk_window_get_origin (app->window, &xpos, &ypos);
 
   i = 0;
-  argv[i++] = (char *)client_data;
+  argv[i++] = (char *) client_data;
   argv[i++] = "-x";
-  argv[i++] = g_strdup_printf ("%d",xpos);
+  argv[i++] = g_strdup_printf ("%d", xpos);
   argv[i++] = "-y";
-  argv[i++] = g_strdup_printf ("%d",ypos);
+  argv[i++] = g_strdup_printf ("%d", ypos);
 
   gnome_client_set_restart_command (client, i, argv);
   /* i.e. clone_command = restart_command - '--sm-client-id' */
@@ -144,13 +150,14 @@ save_state (
 int
 main (int argc, char *argv[])
 {
-  GtkWidget      *errordialog;
-  GtkWidget      *vbox, *menubar, *toolbar, *statusbar;
-  GtkWidget      *handle_box;
-  GtkUIManager   *ui_manager;
-  GnomeClient    *client;
+  GtkWidget *errordialog;
+  GtkWidget *vbox, *menubar, *toolbar, *statusbar, *gridframe;
+  GtkUIManager *ui_manager;
+  GnomeClient *client;
+  GnomeProgram *program;
+  GOptionContext *option_context;
   struct timeval tv;
-  gint           i;
+  gint i;
 
   gettimeofday (&tv, NULL);
   srand (tv.tv_usec);
@@ -161,13 +168,18 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  gnome_program_init (GAME_NAME, VERSION,
- 		      LIBGNOMEUI_MODULE,
- 		      argc, argv,
- 		      GNOME_PARAM_POPT_TABLE, options,
- 		      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+  option_context = g_option_context_new ("");
+  g_option_context_add_main_entries (option_context, options,
+				     GETTEXT_PACKAGE);
 
-  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gnobots2.png");
+  program = gnome_program_init (GAME_NAME, VERSION,
+				LIBGNOMEUI_MODULE,
+				argc, argv,
+				GNOME_PARAM_GOPTION_CONTEXT, option_context,
+				GNOME_PARAM_APP_DATADIR, DATADIR,
+				GNOME_PARAM_NONE);
+
+  gtk_window_set_default_icon_name ("gnome-robots");
 
   client = gnome_master_client ();
 
@@ -175,17 +187,23 @@ main (int argc, char *argv[])
   gtk_object_sink (GTK_OBJECT (client));
 
   g_signal_connect (G_OBJECT (client), "save_yourself",
-                    G_CALLBACK (save_state), argv[0]);
-  g_signal_connect (G_OBJECT(client), "die",
-                    G_CALLBACK (quit_game), argv[0]);
+		    G_CALLBACK (save_state), argv[0]);
+  g_signal_connect (G_OBJECT (client), "die",
+		    G_CALLBACK (quit_game), argv[0]);
 
   initialize_gconf (argc, argv);
 
   app = gnome_app_new (GAME_NAME, _("Robots"));
-  gtk_window_set_resizable (GTK_WINDOW (app), FALSE);
 
   g_signal_connect (G_OBJECT (app), "delete_event",
-                    G_CALLBACK (quit_game), NULL);
+		    G_CALLBACK (quit_game), NULL);
+  g_signal_connect (G_OBJECT (app), "configure_event",
+		    G_CALLBACK (save_window_geometry), NULL);
+  g_signal_connect (G_OBJECT (app), "window_state_event",
+		    G_CALLBACK (window_state_cb), NULL);
+
+
+  set_window_geometry (app);
 
   statusbar = gnobots_statusbar_new ();
   ui_manager = gtk_ui_manager_new ();
@@ -195,11 +213,8 @@ main (int argc, char *argv[])
   gtk_window_add_accel_group (GTK_WINDOW (app),
 			      gtk_ui_manager_get_accel_group (ui_manager));
 
-  handle_box = gtk_handle_box_new ();
   menubar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
   toolbar = gtk_ui_manager_get_widget (ui_manager, "/Toolbar");
-  gtk_widget_set_size_request (toolbar, 250, -1);
-  gtk_container_add (GTK_CONTAINER (handle_box), toolbar);
 
   make_cursors ();
 
@@ -210,76 +225,83 @@ main (int argc, char *argv[])
 		    G_CALLBACK (mouse_cb), NULL);
   g_signal_connect (G_OBJECT (game_area), "motion-notify-event",
 		    G_CALLBACK (move_cb), NULL);
+  g_signal_connect (G_OBJECT (game_area), "configure-event",
+		    G_CALLBACK (resize_cb), NULL);
+  g_signal_connect (G_OBJECT (game_area), "expose-event",
+		    G_CALLBACK (expose_cb), NULL);
+
+  gridframe = games_grid_frame_new (GAME_WIDTH, GAME_HEIGHT);
+  gtk_container_add (GTK_CONTAINER (gridframe), game_area);
 
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), handle_box, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), game_area, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), gridframe, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
 
   gnome_app_set_contents (GNOME_APP (app), vbox);
 
-  gtk_widget_set_size_request (GTK_WIDGET (game_area), 
-                               TILE_WIDTH * GAME_WIDTH,
-                               TILE_HEIGHT * GAME_HEIGHT);
-  gtk_widget_show (game_area);
-  gtk_widget_show (statusbar);
+  gtk_widget_set_size_request (GTK_WIDGET (game_area),
+			       MINIMUM_TILE_WIDTH * GAME_WIDTH,
+			       MINIMUM_TILE_HEIGHT * GAME_HEIGHT);
 
   /* Set the window position if it was set by the session manager */
-  if (session_xpos >= 0 && session_ypos >= 0){
+  if (session_xpos >= 0 && session_ypos >= 0) {
     gtk_window_move (GTK_WINDOW (app), session_xpos, session_ypos);
   }
 
+  gtk_widget_show_all (app);
+
   if (!load_game_configs ()) {
     /* Oops, no configs, we probably haven't been installed properly. */
     errordialog = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR,
-                                          GTK_BUTTONS_OK,
-                                          "<b>%s</b>\n\n%s",
-                                          _("No game data could be found."),
-                                          _("The program Robots was unable to find any valid game configuration files. Please check that the program is installed correctly."));
-    gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (errordialog)->label), TRUE);
+					  GTK_BUTTONS_OK,
+					  "<b>%s</b>\n\n%s",
+					  _("No game data could be found."),
+					  _
+					  ("The program Robots was unable to find any valid game configuration files. Please check that the program is installed correctly."));
+    gtk_label_set_use_markup (GTK_LABEL
+			      (GTK_MESSAGE_DIALOG (errordialog)->label),
+			      TRUE);
     gtk_window_set_resizable (GTK_WINDOW (errordialog), FALSE);
     gtk_dialog_run (GTK_DIALOG (errordialog));
     exit (1);
   }
 
-  gtk_widget_show (app);
-  
-  if (!load_game_graphics ()) {
-    /* Oops, no graphics, we probably haven't been installed properly. */
-    errordialog = gtk_message_dialog_new (GTK_WINDOW (app), 
-					  GTK_DIALOG_MODAL,
-					  GTK_MESSAGE_ERROR,
-                                          GTK_BUTTONS_OK,
-                                          "<b>%s</b>\n\n%s",
-                                          _("Some graphics files are missing or corrupt."),
-                                          _("The program Robots was unable to load all the necessary graphics files. Please check that the program is installed correctly."));
-    gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (errordialog)->label), TRUE);
-
-    gtk_dialog_run (GTK_DIALOG (errordialog));
-    exit (1);
-  }
-
   load_properties ();
 
-  connect_handle_box_to_toolbar_toggle (handle_box);
-  
+  if (!load_game_graphics ()) {
+    /* Oops, no graphics, we probably haven't been installed properly. */
+    errordialog = gtk_message_dialog_new (GTK_WINDOW (app),
+					  GTK_DIALOG_MODAL,
+					  GTK_MESSAGE_ERROR,
+					  GTK_BUTTONS_OK,
+					  "<b>%s</b>\n\n%s",
+					  _
+					  ("Some graphics files are missing or corrupt."),
+					  _
+					  ("The program Robots was unable to load all the necessary graphics files. Please check that the program is installed correctly."));
+    gtk_label_set_use_markup (GTK_LABEL
+			      (GTK_MESSAGE_DIALOG (errordialog)->label),
+			      TRUE);
+
+    gtk_dialog_run (GTK_DIALOG (errordialog));
+    exit (1);
+  }
+
+  connect_toolbar_toggle (toolbar);
+
   init_sound ();
 
   init_game ();
 
   if (cmdline_scenario) {
-    for (i = 0; i < num_game_graphics (); ++i){
-      if (! strcmp (cmdline_scenario, game_graphics_name (i))){
-	set_game_graphics (i);
-	break;
-      }
-    }
+    set_game_graphics (cmdline_scenario);
   }
 
   if (cmdline_config) {
-    for(i = 0; i < num_game_configs (); ++i){
-      if (! strcmp (cmdline_config, game_config_name (i))){
+    for (i = 0; i < num_game_configs (); ++i) {
+      if (!strcmp (cmdline_config, game_config_name (i))) {
 	properties_set_config (i);
 	break;
       }
@@ -290,6 +312,10 @@ main (int argc, char *argv[])
 
   gtk_main ();
 
+  gnome_accelerators_sync ();
+
+  g_object_unref (program);
+
   return 0;
 }
 
