@@ -60,6 +60,7 @@ GtkWidget *statusbar;
 GtkWidget *space;
 GtkWidget *bit;
 GtkWidget *timer;
+GdkGC *bg_gc;
 
 static const GamesScoresCategory scorecats[] = { {"2x2", N_("2\303\2272")},
 {"3x3", N_("3\303\2273")},
@@ -121,7 +122,7 @@ guint timer_timeout = 0;
 gint tile_size = 0;
 gdouble tile_border_size = 3.0;
 gdouble arrow_border_size = 1.5;
-gboolean coloured_tiles = FALSE;
+gboolean coloured_tiles = TRUE;
 gboolean click_to_move = FALSE;
 
 /* The vertices used in the tiles/sockets. These are built using gui_build_vertices() */
@@ -175,25 +176,32 @@ static int tile_faces[16][7] = {
 };
 
 /* Tile segment colours (this is the resistor colour code) */
-static gdouble tile_colours[11][4][3] = {
-  {{ 46,  52,  54}, {  0,   0,   0}, {  0,   0,   0}, {255, 255, 255}}, /* 0 = black */
-  {{233, 185, 110}, {193, 125,  17}, {143,  89,   2}, {255, 255, 255}}, /* 1 = brown */
-  {{239,  41,  41}, {204,   0,   0}, {164,   0,   0}, {255, 255, 255}}, /* 2 = red */
-  {{252, 175,  62}, {245, 121,   0}, {206,  92,   0}, {255, 255, 255}}, /* 3 = orange */
-  {{252, 233,  79}, {237, 212,   0}, {196, 160,   0}, {  0,   0,   0}}, /* 4 = yellow */
-  {{138, 226,  52}, {115, 210,  22}, { 78, 154,   6}, {  0,   0,   0}}, /* 5 = green */
-  {{114, 159, 207}, { 52, 101, 164}, { 32,  74, 135}, {255, 255, 255}}, /* 6 = blue */
-  {{173, 127, 168}, {117,  80, 123}, { 92,  53, 102}, {255, 255, 255}}, /* 7 = violet */
-  {{211, 215, 207}, {186, 189, 182}, {136, 138, 133}, {  0,   0,   0}}, /* 8 = grey */
-  {{255, 255, 255}, {255, 255, 255}, {238, 238, 236}, {  0,   0,   0}},	/* 9 = white */
-  {{255, 255, 255}, {255, 255, 255}, {238, 238, 236}, {  0,   0,   0}}  /* 10 = standard */
+static gdouble tile_colours[11][4][4] = {
+  {{ 46,  52,  54, 255}, {  0,   0,   0, 255}, {  0,   0,   0, 255}, {255, 255, 255, 255}}, /* 0  = black */
+  {{233, 185, 110, 255}, {193, 125,  17, 255}, {143,  89,   2, 255}, {255, 255, 255, 255}}, /* 1  = brown */
+  {{239,  41,  41, 255}, {204,   0,   0, 255}, {164,   0,   0, 255}, {255, 255, 255, 255}}, /* 2  = red */
+  {{252, 175,  62, 255}, {245, 121,   0, 255}, {206,  92,   0, 255}, {255, 255, 255, 255}}, /* 3  = orange */
+  {{252, 233,  79, 255}, {237, 212,   0, 255}, {196, 160,   0, 255}, {  0,   0,   0, 255}}, /* 4  = yellow */
+  {{138, 226,  52, 255}, {115, 210,  22, 255}, { 78, 154,   6, 255}, {  0,   0,   0, 255}}, /* 5  = green */
+  {{114, 159, 207, 255}, { 52, 101, 164, 255}, { 32,  74, 135, 255}, {255, 255, 255, 255}}, /* 6  = blue */
+  {{173, 127, 168, 255}, {117,  80, 123, 255}, { 92,  53, 102, 255}, {255, 255, 255, 255}}, /* 7  = violet */
+  {{211, 215, 207, 255}, {186, 189, 182, 255}, {136, 138, 133, 255}, {  0,   0,   0, 255}}, /* 8  = grey */
+  {{255, 255, 255, 255}, {255, 255, 255, 255}, {238, 238, 236, 255}, {  0,   0,   0, 255}}, /* 9  = white */
+  {{255, 255, 255,  32}, {  0,   0,   0,  32}, {  0,   0,   0,  64}, {  0,   0,   0,   0}}  /* 10 = shadows */
 };
 
+/* The colour to use when tiles are not coloured */
+#define DEFAULT_COLOUR 8
+
+/* The colour to use when drawing the sockets */
+#define SOCKET_COLOUR 10
+
 void make_buffer (GtkWidget *);
 void create_window (void);
 GtkWidget *create_menu (GtkUIManager *);
 void create_mover (void);
 GtkWidget *create_statusbar (void);
+GdkPixmap *default_background_pixmap;
 
 gint expose_space (GtkWidget *, GdkEventExpose *);
 gint button_press_space (GtkWidget *, GdkEventButton *);
@@ -201,15 +209,14 @@ gint button_release_space (GtkWidget *, GdkEventButton *);
 gint button_motion_space (GtkWidget *, GdkEventButton *);
 
 void gui_build_vertices (void);
-void gui_update_colours (GtkStateType state);
 void gui_draw_faces (cairo_t * context, gint xadd, gint yadd, int quads[][7],
-		     int count, guint colours[4]);
+		     int count, guint colours[4], gboolean prelight);
 void gui_draw_arrow (GdkPixmap * target);
 void gui_draw_socket (GdkPixmap * target, GtkStateType state, gint xadd,
 		      gint yadd);
-void gui_draw_number (cairo_t * context, gdouble x, gdouble y, guint number);
+void gui_draw_number (cairo_t * context, gdouble x, gdouble y, guint number, gdouble *colour);
 void gui_draw_tile (GdkPixmap * target, GtkStateType state, gint xadd,
-		    gint yadd, gint north, gint south, gint east, gint west);
+		    gint yadd, gint north, gint south, gint east, gint west, gboolean prelight);
 void gui_draw_pixmap (GdkPixmap *, gint, gint, gboolean);
 void gui_draw_pause (void);
 
@@ -240,12 +247,14 @@ void pause_cb (void);
 void hint_move_cb (void);
 void clickmove_toggle_cb (GtkToggleAction *, gpointer);
 void hint_move (gint, gint, gint, gint);
-void show_score_dialog (gint);
+gint show_score_dialog (gint, gboolean);
+void new_game (void);
 static gint save_state (GnomeClient *, gint, GnomeRestartStyle,
 			gint, GnomeInteractStyle, gint, gpointer);
 static void set_fullscreen_actions (gboolean is_fullscreen);
 static void fullscreen_cb (GtkAction * action);
 static void window_state_cb (GtkWidget * widget, GdkEventWindowState * event);
+static void load_pixmaps (void);
 
 GtkAction *new_game_action;
 GtkAction *pause_action;
@@ -428,12 +437,16 @@ main (int argc, char **argv)
     size = gconf_client_get_int (gconf_client, KEY_GRID_SIZE, NULL);
   if (size < 2 || size > 6)
     size = 3;
+  games_scores_set_category (highscores, scorecats[size - 2].key);
 
+  coloured_tiles = gconf_client_get_bool (gconf_client, KEY_SHOW_COLOURS, NULL);
+  click_to_move = gconf_client_get_bool (gconf_client, KEY_CLICK_MOVE, NULL);
+
+  load_pixmaps ();
   create_window ();
 
   space = gtk_drawing_area_new ();
 
-
   statusbar = create_statusbar ();
 
   ui_manager = gtk_ui_manager_new ();
@@ -455,6 +468,9 @@ main (int argc, char **argv)
 			 GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK
 			 | GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK);
   gtk_widget_realize (space);
+  bg_gc = gdk_gc_new (space->window);
+  gdk_gc_set_tile (bg_gc, default_background_pixmap);
+  gdk_gc_set_fill (bg_gc, GDK_TILED);
 
   g_signal_connect (G_OBJECT (space), "expose_event",
 		    G_CALLBACK (expose_space), NULL);
@@ -754,36 +770,9 @@ gui_build_vertices (void)
   vertices[26][1] = vertices[21][1] + z2;
 }
 
-/* Convert the theme colours to cairo form. I'm sure there must be an easier way than this... */
-void
-gui_update_colours (GtkStateType state)
-{
-  GdkColor *bg;
-  GdkColor *highlight;
-  GdkColor *shadow;
-  GtkStyle *style;
-
-  /* Get the colours used by this style */
-  style = gtk_widget_get_style (space);
-  bg = &style->bg[state];
-  highlight = &style->light[state];
-  shadow = &style->dark[state];
-
-  /* Set the colours to the them default */
-  tile_colours[10][HIGHLIGHT][0] = highlight->red * 255.0 / 65535.0;
-  tile_colours[10][HIGHLIGHT][1] = highlight->green * 255.0 / 65535.0;
-  tile_colours[10][HIGHLIGHT][2] = highlight->blue * 255.0 / 65535.0;
-  tile_colours[10][BASE][0] = bg->red * 255.0 / 65535.0;
-  tile_colours[10][BASE][1] = bg->green * 255.0 / 65535.0;
-  tile_colours[10][BASE][2] = bg->blue * 255.0 / 65535.0;
-  tile_colours[10][SHADOW][0] = shadow->red * 255.0 / 65535.0;
-  tile_colours[10][SHADOW][1] = shadow->green * 255.0 / 65535.0;
-  tile_colours[10][SHADOW][2] = shadow->blue * 255.0 / 65535.0;
-}
-
 void
 gui_draw_faces (cairo_t * context, gint xadd, gint yadd, int quads[][7],
-		int count, guint colours[4])
+		int count, guint colours[4], gboolean prelight)
 {
   int i, j, k;
   int *quad;
@@ -796,10 +785,12 @@ gui_draw_faces (cairo_t * context, gint xadd, gint yadd, int quads[][7],
     /* Set the face colour */
     face = quad[0];
     level = quad[1];
+    if (prelight && level == BASE)
+       level = HIGHLIGHT;
     n_vertices = quad[2];
     colour = tile_colours[colours[face]][level];
     cairo_set_source_rgba (context, colour[0] / 255.0, colour[1] / 255.0,
-			   colour[2] / 255.0, 1.0);
+			   colour[2] / 255.0, colour[3] / 255.0);
 
     k = quad[3];
     cairo_move_to (context, xadd + vertices[k][0], yadd + vertices[k][1]);
@@ -818,13 +809,13 @@ gui_draw_arrow (GdkPixmap * target)
 {
   cairo_t *context;
   gdouble x, y;
-  guint colours[4] = { 10, 10, 10, 10 };
+  guint colours[4] = { SOCKET_COLOUR, SOCKET_COLOUR, SOCKET_COLOUR, SOCKET_COLOUR };
    
   context = gdk_cairo_create (GDK_DRAWABLE (buffer));
      
   x = xborder + size * tile_size;
   y = yborder;
-  gui_draw_faces (context, x, y, arrow_faces, 3, colours);
+  gui_draw_faces (context, x, y, arrow_faces, 3, colours, FALSE);
      
   cairo_destroy (context);
 }
@@ -833,22 +824,21 @@ void
 gui_draw_socket (GdkPixmap * target, GtkStateType state, gint xadd, gint yadd)
 {
   cairo_t *context;
+  guint colours[4] = { SOCKET_COLOUR, SOCKET_COLOUR, SOCKET_COLOUR, SOCKET_COLOUR };
   gdouble *colour;
-  guint colours[4] = { 10, 10, 10, 10 };
+  
+  gdk_draw_rectangle (GDK_DRAWABLE(target), bg_gc, TRUE, xadd, yadd, 
+		      tile_size, tile_size);
 
   context = gdk_cairo_create (GDK_DRAWABLE (target));
 
-  /* Use the theme colours */
-  gui_update_colours (state);
-
   /* Only draw inside the allocated space */
   cairo_rectangle (context, xadd, yadd, tile_size, tile_size);
   cairo_clip (context);
 
   /* Blank the piece */
-  colour = tile_colours[10][BASE];
-  cairo_set_source_rgba (context, colour[0] / 255.0, colour[1] / 255.0,
-			 colour[2] / 255.0, 1.0);
+  colour = tile_colours[SOCKET_COLOUR][BASE];
+  cairo_set_source_rgba (context, colour[0] / 255.0, colour[1] / 255.0, colour[2] / 255.0, colour[3] / 255.0);
   cairo_rectangle (context, xadd, yadd, tile_size, tile_size);
   cairo_fill (context);
 
@@ -858,26 +848,21 @@ gui_draw_socket (GdkPixmap * target, GtkStateType state, gint xadd, gint yadd)
     rebuild_vertices = FALSE;
   }
 
-  gui_draw_faces (context, xadd, yadd, socket_faces, 4, colours);
+  gui_draw_faces (context, xadd, yadd, socket_faces, 4, colours, FALSE);
 
   cairo_destroy (context);
 }
 
 void
-gui_draw_number (cairo_t * context, gdouble x, gdouble y, guint number)
+gui_draw_number (cairo_t * context, gdouble x, gdouble y, guint number, gdouble *colour)
 {
   gchar *text;
   cairo_text_extents_t extents;
-  gdouble *colour;
 
   text = _(translatable_number[number]);
 
-  if (coloured_tiles)
-    colour = tile_colours[number][TEXT];
-  else
-    colour = tile_colours[10][TEXT];
   cairo_set_source_rgba (context, colour[0] / 255.0, colour[1] / 255.0,
-			 colour[2] / 255.0, 1.0);
+			 colour[2] / 255.0, colour[3] / 255.0);
 
   cairo_text_extents (context, text, &extents);
   cairo_move_to (context, x - extents.width / 2.0, y + extents.height / 2.0);
@@ -886,27 +871,29 @@ gui_draw_number (cairo_t * context, gdouble x, gdouble y, guint number)
 
 void
 gui_draw_tile (GdkPixmap * target, GtkStateType state, gint xadd, gint yadd,
-	       gint north, gint south, gint east, gint west)
+	       gint north, gint south, gint east, gint west, gboolean prelight)
 {
   cairo_t *context;
-  gdouble *colour;
   guint colours[4];
 
   context = gdk_cairo_create (GDK_DRAWABLE (target));
 
   /* Use per sector colours or the theme colours */
-  gui_update_colours (state);
   if (coloured_tiles) {
     colours[NORTH] = north;
     colours[SOUTH] = south;
     colours[EAST] = east;
     colours[WEST] = west;
   } else
-    colours[0] = colours[1] = colours[2] = colours[3] = 10;
+    colours[NORTH] = colours[SOUTH] = colours[EAST] = colours[WEST] = DEFAULT_COLOUR;
 
   /* Only draw inside the allocated space */
   cairo_rectangle (context, xadd, yadd, tile_size, tile_size);
   cairo_clip (context);
+   
+  /* Clear background */
+  cairo_set_source_rgba (context, 0.0, 0.0, 0.0, 1.0);
+  cairo_paint (context);
 
   /* Build the co-ordinates used by the tiles */
   if (rebuild_vertices) {
@@ -914,13 +901,11 @@ gui_draw_tile (GdkPixmap * target, GtkStateType state, gint xadd, gint yadd,
     rebuild_vertices = FALSE;
   }
 
-  gui_draw_faces (context, xadd, yadd, tile_faces, 16, colours);
+  gui_draw_faces (context, xadd, yadd, tile_faces, 16, colours, prelight);
 
   /* Draw outline */
   cairo_set_line_width (context, 1.0);
-  colour = tile_colours[10][TEXT];
-  cairo_set_source_rgba (context, colour[0] / 255.0, colour[1] / 255.0,
-			 colour[2] / 255.0, 1.0);
+  cairo_set_source_rgba (context, 0.0, 0.0, 0.0, 1.0);
   cairo_rectangle (context, xadd + 0.5, yadd + 0.5, tile_size - 1.0,
 		   tile_size - 1.0);
   cairo_stroke (context);
@@ -929,13 +914,10 @@ gui_draw_tile (GdkPixmap * target, GtkStateType state, gint xadd, gint yadd,
 			  CAIRO_FONT_WEIGHT_BOLD);
   cairo_set_font_size (context, tile_size / 3.5);
 
-  gui_draw_number (context, xadd + tile_size / 2, yadd + tile_size / 5,
-		   north);
-  gui_draw_number (context, xadd + tile_size / 2, yadd + tile_size * 4 / 5,
-		   south);
-  gui_draw_number (context, xadd + tile_size * 4 / 5, yadd + tile_size / 2,
-		   east);
-  gui_draw_number (context, xadd + tile_size / 5, yadd + tile_size / 2, west);
+  gui_draw_number (context, xadd + tile_size / 2, yadd + tile_size / 5, north, tile_colours[colours[NORTH]][TEXT]);
+  gui_draw_number (context, xadd + tile_size / 2, yadd + tile_size * 4 / 5, south, tile_colours[colours[SOUTH]][TEXT]);
+  gui_draw_number (context, xadd + tile_size * 4 / 5, yadd + tile_size / 2, east, tile_colours[colours[EAST]][TEXT]);
+  gui_draw_number (context, xadd + tile_size / 5, yadd + tile_size / 2, west, tile_colours[colours[WEST]][TEXT]);
 
   cairo_destroy (context);
 }
@@ -960,7 +942,7 @@ button_motion_space (GtkWidget * widget, GdkEventButton * event)
     get_tilexy (event->x, event->y, &x, &y);
     if ((x != oldx) || (y != oldy)) {
       if ((oldx != -1) && (tiles[oldy][oldx].status == USED)) {
-	gui_draw_pixmap (buffer, oldx, oldy, FALSE);
+	 gui_draw_pixmap (buffer, oldx, oldy, FALSE);
       }
       if ((x != -1) && (tiles[y][x].status == USED)) {
 	gui_draw_pixmap (buffer, x, y, TRUE);
@@ -998,7 +980,7 @@ gui_draw_pixmap (GdkPixmap * target, gint x, gint y, gboolean prelight)
 
   if (which == USED)
     gui_draw_tile (target, state, xadd, yadd, tiles[y][x].n, tiles[y][x].s,
-		   tiles[y][x].e, tiles[y][x].w);
+		   tiles[y][x].e, tiles[y][x].w, state);
   else
     gui_draw_socket (target, state, xadd, yadd);
 
@@ -1118,16 +1100,16 @@ setup_mover (gint x, gint y, gint status)
     if (mover.pixmap)
       g_object_unref (mover.pixmap);
     mover.pixmap = NULL;
-    if (game_over ()) {
+    if (game_over () && game_state != gameover) {
       game_state = gameover;
       games_clock_stop (GAMES_CLOCK (timer));
       set_game_menu_items_sensitive (FALSE);
       if (!have_been_hinted) {
 	message (_("Puzzle solved! Well done!"));
-	game_score ();
       } else {
 	message (_("Puzzle solved!"));
       }
+      game_score ();
     }
     update_move_menu_sensitivity ();
     return 1;
@@ -1231,11 +1213,12 @@ game_over (void)
   return 1;
 }
 
-void
-show_score_dialog (gint pos)
+gint
+show_score_dialog (gint pos, gboolean endofgame)
 {
   static GtkWidget *scoresdialog = NULL;
   gchar *message;
+  gint result;
 
   if (!scoresdialog) {
     scoresdialog = games_scores_dialog_new (highscores, _("Tetravex Scores"));
@@ -1255,31 +1238,45 @@ show_score_dialog (gint pos)
 				     NULL);
   }
 
-  gtk_dialog_run (GTK_DIALOG (scoresdialog));
+  if (endofgame) {
+    games_scores_dialog_set_buttons (GAMES_SCORES_DIALOG (scoresdialog),
+				     GAMES_SCORES_QUIT_BUTTON |
+				     GAMES_SCORES_NEW_GAME_BUTTON);
+  } else {
+    games_scores_dialog_set_buttons (GAMES_SCORES_DIALOG (scoresdialog), 0);
+  }
+
+  result = gtk_dialog_run (GTK_DIALOG (scoresdialog));
   gtk_widget_hide (scoresdialog);
+
+  return result;
 }
 
 void
 score_cb (GtkAction * action, gpointer data)
 {
-  gchar *level;
-  level = g_strdup_printf ("%dx%d", size, size);
-  show_score_dialog (0);
-  g_free (level);
+  show_score_dialog (0, FALSE);
 }
 
 void
 game_score (void)
 {
-  gint pos;
+  gint pos = 0;
   time_t seconds;
   GamesScoreValue score;
 
-  seconds = GAMES_CLOCK (timer)->stopped;
-  games_clock_set_seconds (GAMES_CLOCK (timer), (int) seconds);
-  score.time_double = (gfloat) (seconds / 60) + (gfloat) (seconds % 60) / 100;
-  pos = games_scores_add_score (highscores, score);
-  show_score_dialog (pos);
+  if (!have_been_hinted) {
+    seconds = GAMES_CLOCK (timer)->stopped;
+    games_clock_set_seconds (GAMES_CLOCK (timer), (int) seconds);
+    score.time_double = (gfloat) (seconds / 60) + (gfloat) (seconds % 60) / 100;
+    pos = games_scores_add_score (highscores, score);
+  }
+
+  if (show_score_dialog (pos, TRUE) == GTK_RESPONSE_REJECT) {
+    gtk_main_quit ();
+  } else {
+    new_game ();
+  }
 }
 
 void
@@ -1342,9 +1339,9 @@ redraw_all (void)
   region = gdk_drawable_get_clip_region (GDK_DRAWABLE (space->window));
   gdk_window_begin_paint_region (space->window, region);
 
-  gdk_draw_rectangle (buffer, space->style->bg_gc[GTK_STATE_NORMAL],
-		      TRUE, 0, 0, -1, -1);
   gdk_window_clear (space->window);
+  gdk_draw_rectangle (space->window, bg_gc, TRUE, 0, 0, -1, -1);
+  gdk_draw_rectangle (buffer, bg_gc, TRUE, 0, 0, -1, -1);
   for (y = 0; y < size; y++)
     for (x = 0; x < size * 2; x++)
       gui_draw_pixmap (buffer, x, y, FALSE);
@@ -1545,6 +1542,7 @@ gui_draw_pause (void)
 
   region = gdk_drawable_get_clip_region (GDK_DRAWABLE (space->window));
   gdk_window_begin_paint_region (space->window, region);
+  gdk_draw_rectangle (space->window, bg_gc, TRUE, 0, 0, -1, -1);
 
   for (y = 0; y < size; y++) {
     for (x = 0; x < size * 2; x++) {
@@ -1556,7 +1554,7 @@ gui_draw_pause (void)
 
       if (which == USED)
 	gui_draw_tile (buffer, GTK_STATE_NORMAL, xadd, yadd, tiles[y][x].n,
-		       tiles[y][x].s, tiles[y][x].e, tiles[y][x].w);
+		       tiles[y][x].s, tiles[y][x].e, tiles[y][x].w, FALSE);
       else
 	gui_draw_socket (buffer, GTK_STATE_NORMAL, xadd, yadd);
 
@@ -1616,15 +1614,9 @@ create_menu (GtkUIManager * ui_manager)
   gtk_action_group_add_toggle_actions (action_group, toggles,
 				       G_N_ELEMENTS (toggles), NULL);
   action = gtk_action_group_get_action (action_group, "Colours");
-  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-				gconf_client_get_bool (gconf_client,
-						       KEY_SHOW_COLOURS,
-						       NULL));
+  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), coloured_tiles);
   action = gtk_action_group_get_action (action_group, "ClickToMove");
-  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-				gconf_client_get_bool (gconf_client,
-						       KEY_CLICK_MOVE,
-						       NULL));
+  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), click_to_move);
 
   for (i = 0; i < G_N_ELEMENTS (size_action_entry); i++)
     size_action[i] =
@@ -1647,8 +1639,7 @@ make_buffer (GtkWidget * widget)
 }
 
 void
-new_game_cb (GtkAction * action, gpointer data)
-{
+new_game (){
   gchar *str;
 
   new_board (size);
@@ -1665,6 +1656,12 @@ new_game_cb (GtkAction * action, gpointer data)
   g_free (str);
 }
 
+void
+new_game_cb (GtkAction * action, gpointer data)
+{
+  new_game ();
+}
+
 void
 quit_game_cb (void)
 {
@@ -1965,3 +1962,40 @@ window_state_cb (GtkWidget * widget, GdkEventWindowState * event)
     set_fullscreen_actions (event->new_window_state &
 			    GDK_WINDOW_STATE_FULLSCREEN);
 }
+
+static GdkPixmap *
+get_pixmap (const char *filename)
+{
+  GdkPixmap *ret;
+  GdkPixbuf *im;
+  char *fullname = gnome_program_locate_file (NULL,
+					      GNOME_FILE_DOMAIN_APP_PIXMAP,
+					      filename, TRUE, NULL);
+
+  if (fullname == NULL)
+    return NULL;
+
+  im = gdk_pixbuf_new_from_file (fullname, NULL);
+  if (im != NULL) {
+    gdk_pixbuf_render_pixmap_and_mask_for_colormap (im,
+						    gdk_colormap_get_system
+						    (), &ret, NULL, 127);
+    gdk_pixbuf_unref (im);
+  } else {
+    ret = NULL;
+  }
+  g_free (fullname);
+
+  return ret;
+}
+
+static void
+load_pixmaps (void)
+{
+  gchar *buffer;
+
+  buffer = g_build_filename (PIXMAPDIR, "gnotravex", "baize.png", NULL);
+  default_background_pixmap = get_pixmap (buffer);
+  g_free (buffer);
+}
+
